Create R6 reference object class elementarysampleraw
new()Initialize function for R6 elementarysampleraw class.
elementarysampleraw$new(
trip_id,
well_id,
well_id_source,
sample_id,
sub_sample_id,
sub_sample_total_count_id,
elementarysampleraw_id,
sample_quality_code,
sample_type_code,
species_fao_code,
size_measure_type_code,
sample_total_count,
sample_number_measured,
sample_length_class
)trip_idObject of class character expected. Trip identification.
well_idObject of class character expected. Well identification. For the Observe database, the topiaid field from the table ps_logbook.well of the database is used; if it is missing, the well ID is generated by the t3 process, as follows: well_id="fr.ird.data.ps.logbook.Well#trip_id#well_label". For the AVDTH database, well identification is always generated by T3 process such as: well_id="fr.ird.avdth.entities.data.Well#vessel_code#trip_end_date#N_CUVE.F_POS_CUVE" .
well_id_sourceObject of class character expected. Source of the well identification: "Observe" if the topiaid field from Observe database is used or "T3" if the the well ID is generated by the t3 process.
sample_idObject of class character expected. Sample identification.
sub_sample_idObject of class integer expected. Sub sample identification.
sub_sample_total_count_idObject of class integer expected. Sub sample identification bis in relation with the fish total count.
elementarysampleraw_idObject of class character expected. Elementary sample raw identification.
sample_quality_codeObject of class integer expected. Sample quality identification.
sample_type_codeObject of class integer expected. Sample type identification.
species_fao_codeObject of class character expected. Specie code identification on 3 characters.
size_measure_type_codeObject of class integer expected. Length type identification.
sample_total_countObject of class integer expected. Sample number of total individuals counted.
sample_number_measuredObject of class integer expected. Sample number of measured individuals.
sample_length_classObject of class double expected. Sample length class of measured individuals.