Create R6 reference object class elementarywellplans

Super class

list_t3 -> elementarywellplans

Methods

Inherited methods


elementarywellplans$new()

Initialize function for R6 elementarywellplans class.

Usage

Arguments

...

(empty, list or R6-elementarywellplan classes) Nothing, a list of object R6-elementarywellplan classes or one object R6-elementarywellplan classes.


elementarywellplans$add()

Function for add a new elementarywellplan in the object elementarywellplans.

Usage

elementarywellplans$add(new_item)

Arguments

new_item

(list or R6-elementarywellplan classes) A list of object R6-elementarywellplan classes or one object R6-elementarywellplan classes.


elementarywellplans$filter_by_trip()

Function for filter elementarywellplans by trip identification.

Usage

elementarywellplans$filter_by_trip(trip_id)

Arguments

trip_id

(character) Trip identification.


elementarywellplans$clone()

The objects of this class are cloneable with this method.

Usage

elementarywellplans$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.