Create R6 reference object class trips

Super class

list_t3 -> trips

Methods

Inherited methods


trips$new()

Initialize function for R6 trips class.

Usage

trips$new(...)

Arguments

...

(empty, list or R6-trip classes) Nothing, a list of object R6-trip classes or one object R6-trip classes.


trips$add()

Function for add a new trip in the object trips

Usage

trips$add(new_item)

Arguments

new_item

(list or R6-trip classes) A list of object R6-trip classes or one object R6-trip classes.


trips$clone()

The objects of this class are cloneable with this method.

Usage

trips$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.