Create R6 reference object class well

Methods

Public methods


well$new()

Initialize function for R6 well class.

Usage

well$new(
  trip_id,
  well_id,
  well_id_source,
  well_minus10_weight,
  well_plus10_weight,
  well_global_weight
)

Arguments

trip_id

Object of class character expected. Trip identification.

well_id

Object of class character expected. Well identification. For the Observe database, the topiaid field from the table ps_logbook.well of the database is used; if it is missing, the well ID is generated by the t3 process, as follows: well_id="fr.ird.data.ps.logbook.Well#trip_id#well_label". For the AVDTH database, well identification is always generated by T3 process such as: well_id="fr.ird.avdth.entities.data.Well#vessel_code#trip_end_date#N_CUVE.F_POS_CUVE" .

well_id_source

Object of class character expected. Source of the well identification: "Observe" if the topiaid field from Observe database is used or "T3" if the the well ID is generated by the t3 process.

well_minus10_weight

Object of class integer expected. Catch weight of individuals in the less than 10 kg category (by well, in tonne, considering all species).

well_plus10_weight

Object of class integer expected. Catch weight of individuals in the over 10 kg category (by well, in tonne, considering all species).

well_global_weight

Object of class integer expected. Catch weight of individuals (less and more than 10kg categories, by well, in tonne, considering all species).


well$clone()

The objects of this class are cloneable with this method.

Usage

well$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.