Create R6 reference object class wells

Super class

list_t3 -> wells

Methods

Inherited methods


wells$new()

Initialize function for R6 wells class.

Usage

wells$new(...)

Arguments

...

(empty, list or R6-well classes) Nothing, a list of object R6-well classes or one object R6-well classes.


wells$add()

Function for add a new well in the object wells.

Usage

wells$add(new_item)

Arguments

new_item

(list or R6-well classes) A list of object R6-well classes or one object R6-well classes.


wells$filter_by_trip()

Function for filter well by trip identification.

Usage

wells$filter_by_trip(trip_id)

Arguments

trip_id

(character) Trip identification.


wells$clone()

The objects of this class are cloneable with this method.

Usage

wells$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.