Create R6 reference object class elementarywellplan
new()Initialize function for R6 elementarywellplan class.
elementarywellplan$new(
wellplan_id,
well_id,
well_id_source,
activity_id,
school_type_code,
sample_id,
species_fao_code,
wellplan_weight,
wellplan_count,
weight_category_code,
weight_category_label
)wellplan_idObject of class character expected. Wellplan identification.
well_idObject of class character expected. Well identification. For the Observe database, the topiaid field from the table ps_logbook.well of the database is used; if it is missing, the well ID is generated by the t3 process, as follows: well_id="fr.ird.data.ps.logbook.Well#trip_id#well_label". For the AVDTH database, well identification is always generated by T3 process such as: well_id="fr.ird.avdth.entities.data.Well#vessel_code#trip_end_date#N_CUVE.F_POS_CUVE" .
well_id_sourceObject of class character expected. Source of the well identification: "Observe" if the topiaid field from Observe database is used or "T3" if the the well ID is generated by the t3 process.
activity_idObject of class character expected. Activity identification.
school_type_codeObject of class character expected. School type identification.
sample_idObject of class character expected. Sample identification.
species_fao_codeObject of class character expected. Specie code identification on 3 characters.
wellplan_weight(numeric) Weight in tonnes filled in the well plan.
wellplan_countObject of class integer expected. Well plan number of individus.
weight_category_codeObject of class character expected. Well plan category code identification.
weight_category_labelObject of class character expected. Well plan weight category identification.