Create R6 reference object class wellset

Methods


Method new()

Initialize function for R6 wellset class.

Usage

wellset$new(
  trip_id,
  activity_id,
  school_type_code,
  well_id,
  well_id_source,
  sample_id,
  weighted_weight,
  weighted_weight_minus10,
  weighted_weight_plus10
)

Arguments

trip_id

Object of class character expected. Trip identification.

activity_id

Object of class character expected. Activity identification.

school_type_code

Object of class character expected. School type identification.

well_id

Object of class character expected. Well identification. For the Observe database, the topiaid field from the table ps_logbook.well of the database is used; if it is missing, the well ID is generated by the t3 process, as follows: well_id="fr.ird.data.ps.logbook.Well#trip_id#well_label". For the AVDTH database, well identification is always generated by T3 process such as: well_id="fr.ird.avdth.entities.data.Well#vessel_code#trip_end_date#N_CUVE.F_POS_CUVE" .

well_id_source

Object of class character expected. Source of the well identification: "Observe" if the topiaid field from Observe database is used or "T3" if the the well ID is generated by the t3 process.

sample_id

Object of class character expected. Sample identification.

weighted_weight

Object of class numeric expected. Set weight weighted by all set in the well(s) (tonnes).

weighted_weight_minus10

Object of class numeric expected. Set weight of individuals in the less than 10 kg category, in tonnes, (weighted by all set in the well(s)).

weighted_weight_plus10

Object of class numeric expected. Set weight of individuals in the over 10 kg category, in tonnes, (weighted by all set in the well(s)).


Method clone()

The objects of this class are cloneable with this method.

Usage

wellset$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.